# Generated by Django 3.1.8 on 2021-05-11 16:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('streamfield', '0002_gallery_stream'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Gallery',
        ),
    ]
