# Generated by Django 3.2.3 on 2021-10-03 15:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0002_alter_custommenu_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='custommenu',
            name='id',
        ),
        migrations.AlterField(
            model_name='custommenu',
            name='name',
            field=models.CharField(choices=[('top', 'Horní menu'), ('footer', 'Patička')], max_length=50, primary_key=True, serialize=False),
        ),
    ]
