# Generated by Django 3.2.3 on 2021-10-03 16:14

from django.db import migrations
import wagtail.core.blocks
import wagtail.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ('custom_menu', '0005_alter_custommenu_content'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='custommenu',
            name='content',
        ),
        migrations.AddField(
            model_name='custommenu',
            name='stream',
            field=wagtail.core.fields.StreamField([('containers', wagtail.core.blocks.StructBlock([('stream', wagtail.core.blocks.StreamBlock([('container', wagtail.core.blocks.StructBlock([('stream', wagtail.core.blocks.StreamBlock([('linkblock', wagtail.core.blocks.StructBlock([('name', wagtail.core.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.core.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.core.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka')], label='The icon'))]))], label='Content of Column'))], icon='doc-full', label='Column'))], label='Columns'))], icon='container', label='More Columns')), ('linkblock', wagtail.core.blocks.StructBlock([('name', wagtail.core.blocks.TextBlock(help_text='Name of the link', max_length=50, required=True)), ('page', wagtail.core.blocks.PageChooserBlock(label='A page to be opened')), ('icon', wagtail.core.blocks.ChoiceBlock(choices=[('none', 'None'), ('pencil', 'Tužka')], label='The icon'))]))], default=[]),
        ),
    ]
